@@ -4,6 +4,7 @@ from braintree.resource import Resource
 from braintree.address import Address
 from braintree.configuration import Configuration
 from braintree.transparent_redirect import TransparentRedirect
+from braintree.credit_card_verification import CreditCardVerification
 
 class CreditCard(Resource):
     """
@@ -175,6 +176,32 @@ class CreditCard(Resource):
         """
         return Configuration.gateway().credit_card.find(credit_card_token)
 
+    @staticmethod
+    def forward(credit_card_token, receiving_merchant_id):
+        """
+        Create a nonce for a credit card in your Braintree vault that can be used by another Braintree merchant.
+
+        A credit card token and a receiving merchant ID are required:
+
+            result = braintree.CreditCard.forward(
+                credit_card.token,
+                "another_merchant_public_id"
+            })
+        """
+
+        return Configuration.gateway().credit_card.forward(credit_card_token, receiving_merchant_id)
+
+    @staticmethod
+    def from_nonce(nonce):
+        """
+        Convert a payment method nonce into a CreditCard. This does not return
+        a result object. This will raise a :class:`NotFoundError <braintree.exceptions.not_found_error.NotFoundError>` if the provided
+        credit_card_id is not found. ::
+
+            credit_card = braintree.CreditCard.from_nonce("my_payment_method_nonce")
+        """
+        return Configuration.gateway().credit_card.from_nonce(nonce)
+
     @staticmethod
     def create_signature():
         return CreditCard.signature("create")
@@ -189,11 +216,12 @@ class CreditCard(Resource):
             "company", "country_code_alpha2", "country_code_alpha3", "country_code_numeric", "country_name",
             "extended_address", "first_name", "last_name", "locality", "postal_code", "region", "street_address"
         ]
-        options = ["make_default", "verification_merchant_account_id", "verify_card", "venmo_sdk_session"]
+        options = ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session"]
 
         signature = [
             "billing_address_id", "cardholder_name", "cvv", "expiration_date", "expiration_month", "expiration_year",
-            "device_session_id", "number", "token", "venmo_sdk_payment_method_code", "device_data",
+            "device_session_id", "fraud_merchant_id", "number", "token", "venmo_sdk_payment_method_code", "device_data",
+            "payment_method_nonce",
             {"billing_address": billing_address_params},
             {"options": options}
         ]
@@ -254,6 +282,11 @@ class CreditCard(Resource):
         if "subscriptions" in attributes:
             self.subscriptions = [braintree.subscription.Subscription(gateway, subscription) for subscription in self.subscriptions]
 
+        if "verifications" in attributes:
+            sorted_verifications = sorted(attributes["verifications"], key=lambda verification: verification["created_at"], reverse=True)
+            if len(sorted_verifications) > 0:
+                self.verification = CreditCardVerification(gateway, sorted_verifications[0])
+
     @property
     def expiration_date(self):
         return self.expiration_month + "/" + self.expiration_year
